<?php
if(!class_exists('WP_List_Table')) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class Linkmonetizer_List_Table extends WP_List_Table {
    function __construct() {
//         $options = get_option(TN_ADBAR_OPTION);
        parent::__construct(array(
            'singular'  => 'link',
            'plural'    => 'links',
            'ajax'      => false
        ));
        
    }

    function extra_tablenav($which) {
        echo '<div class="alignleft actions">';
        submit_button(__('Create new link'), 'button-secondary action',
                'new-link-'.$which, false);
        echo '</div>';
    }
    
    function get_table_classes() {
      return array('links', 'widefat');
    }

    function column_default($item, $column_name) {
        return $item[$column_name];
    }
    
    function column_url($item) {
        $link = home_url($item['slug']);
        return "<a href=\"$link\">$link</a>";
    }

    function column_slug($item) {
        return "<a class=\"link-edit\" href=\"\">{$item['slug']}</a>";
    }
    
    function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="%s[]" value="%s" />',
            $this->_args['singular'], $item['id']
        );
    }
    
    function get_columns(){
        $columns = array(
            'cb'            => '<input type="checkbox" />',
            'slug'          => 'Slug',
            'url'           => 'URL',
            'firstlink'     => 'First Link',
            'firstcount'    => 'Clicks',
            'secondlink'    => 'Second Link',
            'secondcount'   => 'Clicks'
        );
        return $columns;
    }
    
    function get_sortable_columns() {
        $sortable_columns = array(
            'slug'          => array('slug', false),
            'firstlink'     => array('firstlink', false),
            'firstcount'    => array('firstclicks', false),
            'secondlink'    => array('secondlink', false),
            'secondcount'   => array('secondclicks', false)
        );
        return $sortable_columns;
    }
    
    function get_bulk_actions() {
        $actions = array(
            'delete'        => 'Delete',
            'resetstats'    => 'Reset stats'
        );
        return $actions;
    }
    
    function process_bulk_action() {
        if (!isset($_REQUEST[$this->_args['singular']])) return;
        if ('delete' === $this->current_action()) {
            check_admin_referer(TN_PLUGIN_FOLDER.'_nonce',
                                 TN_PLUGIN_FOLDER.'_nonce');
            if (false !== tnlm_delete_links(
                            $_REQUEST[$this->_args['singular']])) {
                echo '<div class="updated"><p>Items deleted.</p></div>';
            } else {
                echo '<div class="error"><p>Error deleting items.</p></div>';
            }
        } elseif ('resetstats' === $this->current_action()) {
            check_admin_referer(TN_PLUGIN_FOLDER.'_nonce',
                                 TN_PLUGIN_FOLDER.'_nonce');
            if (false !== tnlm_reset_links(
                            $_REQUEST[$this->_args['singular']])) {
                echo '<div class="updated"><p>Items reset.</p></div>';
            } else {
                echo '<div class="error"><p>Error resetting items.</p></div>';
            }
        }
    }
    
    function prepare_items() {
        $per_page = 10; // items to show per page
        
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        
        $this->process_bulk_action(); // if there is a bulk action

        $orderby = (!empty($_REQUEST['orderby'])) ?
                                $_REQUEST['orderby'] : 'id';
        $order = (!empty($_REQUEST['order'])) ? $_REQUEST['order'] : 'asc';
        $data = tnlm_get_link_data($orderby, $order);

        $current_page = $this->get_pagenum();
        $total_items = count($data);
        $data = array_slice($data, (($current_page-1)*$per_page), $per_page);
        $this->items = $data;
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page'    => $per_page,
            'total_pages' => ceil($total_items/$per_page)
        ));
    }
}
